pub enum RpcTransactionResponse {
Variant0 {
final_execution_status: TxExecutionStatus,
receipts: Vec<ReceiptView>,
receipts_outcome: Vec<ExecutionOutcomeWithIdView>,
status: FinalExecutionStatus,
transaction: SignedTransactionView,
transaction_outcome: ExecutionOutcomeWithIdView,
},
Variant1 {
final_execution_status: TxExecutionStatus,
receipts_outcome: Vec<ExecutionOutcomeWithIdView>,
status: FinalExecutionStatus,
transaction: SignedTransactionView,
transaction_outcome: ExecutionOutcomeWithIdView,
},
}Expand description
RpcTransactionResponse
JSON schema
{
"type": "object",
"anyOf": [
{
"$ref": "#/components/schemas/FinalExecutionOutcomeWithReceiptView"
},
{
"$ref": "#/components/schemas/FinalExecutionOutcomeView"
}
],
"required": [
"final_execution_status"
],
"properties": {
"final_execution_status": {
"$ref": "#/components/schemas/TxExecutionStatus"
}
}
}Variants
Variant0
Fields
final_execution_status: TxExecutionStatusreceipts: Vec<ReceiptView>Receipts generated from the transaction
receipts_outcome: Vec<ExecutionOutcomeWithIdView>The execution outcome of receipts.
status: FinalExecutionStatusExecution status defined by chain.rs:get_final_transaction_result FinalExecutionStatus::NotStarted - the tx is not converted to the receipt yet FinalExecutionStatus::Started - we have at least 1 receipt, but the first leaf receipt_id (using dfs) hasn’t finished the execution FinalExecutionStatus::Failure - the result of the first leaf receipt_id FinalExecutionStatus::SuccessValue - the result of the first leaf receipt_id
transaction: SignedTransactionViewSigned Transaction
transaction_outcome: ExecutionOutcomeWithIdViewThe execution outcome of the signed transaction.
Variant1
Fields
final_execution_status: TxExecutionStatusreceipts_outcome: Vec<ExecutionOutcomeWithIdView>The execution outcome of receipts.
status: FinalExecutionStatusExecution status defined by chain.rs:get_final_transaction_result FinalExecutionStatus::NotStarted - the tx is not converted to the receipt yet FinalExecutionStatus::Started - we have at least 1 receipt, but the first leaf receipt_id (using dfs) hasn’t finished the execution FinalExecutionStatus::Failure - the result of the first leaf receipt_id FinalExecutionStatus::SuccessValue - the result of the first leaf receipt_id
transaction: SignedTransactionViewSigned Transaction
transaction_outcome: ExecutionOutcomeWithIdViewThe execution outcome of the signed transaction.