pub struct SignableMessage<'a, T> {
pub discriminant: MessageDiscriminant,
pub msg: &'a T,
}Expand description
A wrapper around a message that should be signed using this scheme.
Only used for constructing a signature, not used to transmit messages. The discriminant prefix is implicit and should be known by the receiver based on the context in which the message is received.
Fields
discriminant: MessageDiscriminantmsg: &'a T