pub struct AddGasKeyAction {
pub public_key: PublicKey,
pub num_nonces: u32,
pub permission: AccessKeyPermission,
}Fields
public_key: PublicKeynum_nonces: u32permission: AccessKeyPermissionTrait Implementations
Sourceimpl BorshDeserialize for AddGasKeyAction
impl BorshDeserialize for AddGasKeyAction
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AddGasKeyAction
impl BorshSerialize for AddGasKeyAction
Sourceimpl Clone for AddGasKeyAction
impl Clone for AddGasKeyAction
Sourcefn clone(&self) -> AddGasKeyAction
fn clone(&self) -> AddGasKeyAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddGasKeyAction
impl Debug for AddGasKeyAction
Sourceimpl<'de> Deserialize<'de> for AddGasKeyAction
impl<'de> Deserialize<'de> for AddGasKeyAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AddGasKeyAction
impl PartialEq for AddGasKeyAction
Sourceimpl Serialize for AddGasKeyAction
impl Serialize for AddGasKeyAction
Sourceimpl TryFrom<AddGasKeyAction> for AddGasKeyAction
impl TryFrom<AddGasKeyAction> for AddGasKeyAction
Sourcetype Error = DataConversionError
type Error = DataConversionError
The type returned in the event of a conversion error.
impl Eq for AddGasKeyAction
impl StructuralPartialEq for AddGasKeyAction