pub struct CreateAccountAction {}Trait Implementations
Sourceimpl BorshDeserialize for CreateAccountAction
impl BorshDeserialize for CreateAccountAction
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateAccountAction
impl BorshSerialize for CreateAccountAction
Sourceimpl Clone for CreateAccountAction
impl Clone for CreateAccountAction
Sourcefn clone(&self) -> CreateAccountAction
fn clone(&self) -> CreateAccountAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateAccountAction
impl Debug for CreateAccountAction
Sourceimpl<'de> Deserialize<'de> for CreateAccountAction
impl<'de> Deserialize<'de> for CreateAccountAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CreateAccountAction> for CreateAccountAction
impl From<CreateAccountAction> for CreateAccountAction
Sourcefn from(_: CreateAccountAction) -> Self
fn from(_: CreateAccountAction) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CreateAccountAction
impl PartialEq for CreateAccountAction
Sourceimpl Serialize for CreateAccountAction
impl Serialize for CreateAccountAction
impl Eq for CreateAccountAction
impl StructuralPartialEq for CreateAccountAction