pub struct DeterministicAccountStateInitV1 {
pub code: GlobalContractIdentifier,
pub data: BTreeMap<Vec<u8>, Vec<u8>>,
}Fields
code: GlobalContractIdentifierdata: BTreeMap<Vec<u8>, Vec<u8>>Trait Implementations
Sourceimpl BorshDeserialize for DeterministicAccountStateInitV1
impl BorshDeserialize for DeterministicAccountStateInitV1
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for DeterministicAccountStateInitV1
impl Clone for DeterministicAccountStateInitV1
Sourcefn clone(&self) -> DeterministicAccountStateInitV1
fn clone(&self) -> DeterministicAccountStateInitV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for DeterministicAccountStateInitV1
impl<'de> Deserialize<'de> for DeterministicAccountStateInitV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeterministicAccountStateInitV1
Sourceimpl PartialEq for DeterministicAccountStateInitV1
impl PartialEq for DeterministicAccountStateInitV1
Sourcefn eq(&self, other: &DeterministicAccountStateInitV1) -> bool
fn eq(&self, other: &DeterministicAccountStateInitV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeterministicAccountStateInitV1