pub struct FunctionCallAction {
pub method_name: String,
pub args: Vec<u8>,
pub gas: NearGas,
pub deposit: NearToken,
}Fields
method_name: Stringargs: Vec<u8>gas: NearGasdeposit: NearTokenTrait Implementations
Sourceimpl BorshDeserialize for FunctionCallAction
impl BorshDeserialize for FunctionCallAction
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FunctionCallAction
impl BorshSerialize for FunctionCallAction
Sourceimpl Clone for FunctionCallAction
impl Clone for FunctionCallAction
Sourcefn clone(&self) -> FunctionCallAction
fn clone(&self) -> FunctionCallAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionCallAction
impl Debug for FunctionCallAction
Sourceimpl<'de> Deserialize<'de> for FunctionCallAction
impl<'de> Deserialize<'de> for FunctionCallAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FunctionCallAction
impl PartialEq for FunctionCallAction
Sourceimpl Serialize for FunctionCallAction
impl Serialize for FunctionCallAction
Sourceimpl TryFrom<FunctionCallAction> for FunctionCallAction
impl TryFrom<FunctionCallAction> for FunctionCallAction
Sourcetype Error = DataConversionError
type Error = DataConversionError
The type returned in the event of a conversion error.
impl Eq for FunctionCallAction
impl StructuralPartialEq for FunctionCallAction