pub struct FunctionCallPermission {
pub allowance: Option<NearToken>,
pub receiver_id: String,
pub method_names: Vec<String>,
}Fields
allowance: Option<NearToken>receiver_id: Stringmethod_names: Vec<String>Trait Implementations
Sourceimpl BorshDeserialize for FunctionCallPermission
impl BorshDeserialize for FunctionCallPermission
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for FunctionCallPermission
impl Clone for FunctionCallPermission
Sourcefn clone(&self) -> FunctionCallPermission
fn clone(&self) -> FunctionCallPermission
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionCallPermission
impl Debug for FunctionCallPermission
Sourceimpl<'de> Deserialize<'de> for FunctionCallPermission
impl<'de> Deserialize<'de> for FunctionCallPermission
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FunctionCallPermission
impl PartialEq for FunctionCallPermission
Sourceimpl Serialize for FunctionCallPermission
impl Serialize for FunctionCallPermission
Sourceimpl TryFrom<FunctionCallPermission> for FunctionCallPermission
impl TryFrom<FunctionCallPermission> for FunctionCallPermission
Sourcetype Error = DataConversionError
type Error = DataConversionError
The type returned in the event of a conversion error.
impl Eq for FunctionCallPermission
impl StructuralPartialEq for FunctionCallPermission