pub struct TransferToGasKeyAction {
pub public_key: PublicKey,
pub deposit: NearToken,
}Fields
public_key: PublicKeydeposit: NearTokenTrait Implementations
Sourceimpl BorshDeserialize for TransferToGasKeyAction
impl BorshDeserialize for TransferToGasKeyAction
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for TransferToGasKeyAction
impl Clone for TransferToGasKeyAction
Sourcefn clone(&self) -> TransferToGasKeyAction
fn clone(&self) -> TransferToGasKeyAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferToGasKeyAction
impl Debug for TransferToGasKeyAction
Sourceimpl<'de> Deserialize<'de> for TransferToGasKeyAction
impl<'de> Deserialize<'de> for TransferToGasKeyAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransferToGasKeyAction
impl PartialEq for TransferToGasKeyAction
Sourceimpl Serialize for TransferToGasKeyAction
impl Serialize for TransferToGasKeyAction
Sourceimpl TryFrom<TransferToGasKeyAction> for TransferToGasKeyAction
impl TryFrom<TransferToGasKeyAction> for TransferToGasKeyAction
Sourcetype Error = DataConversionError
type Error = DataConversionError
The type returned in the event of a conversion error.
impl Eq for TransferToGasKeyAction
impl StructuralPartialEq for TransferToGasKeyAction