pub struct TransactionV0 {
pub signer_id: AccountId,
pub public_key: PublicKey,
pub nonce: Nonce,
pub receiver_id: AccountId,
pub block_hash: CryptoHash,
pub actions: Vec<Action>,
}Fields
signer_id: AccountIdpublic_key: PublicKeynonce: Noncereceiver_id: AccountIdblock_hash: CryptoHashactions: Vec<Action>Trait Implementations
Sourceimpl BorshDeserialize for TransactionV0
impl BorshDeserialize for TransactionV0
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TransactionV0
impl BorshSerialize for TransactionV0
Sourceimpl Clone for TransactionV0
impl Clone for TransactionV0
Sourcefn clone(&self) -> TransactionV0
fn clone(&self) -> TransactionV0
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionV0
impl Debug for TransactionV0
Sourceimpl<'de> Deserialize<'de> for TransactionV0
impl<'de> Deserialize<'de> for TransactionV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransactionV0
impl PartialEq for TransactionV0
Sourceimpl Serialize for TransactionV0
impl Serialize for TransactionV0
impl Eq for TransactionV0
impl StructuralPartialEq for TransactionV0