pub struct TransactionV1 {
pub signer_id: AccountId,
pub public_key: PublicKey,
pub nonce: Nonce,
pub receiver_id: AccountId,
pub block_hash: CryptoHash,
pub actions: Vec<Action>,
pub priority_fee: u64,
}Fields
signer_id: AccountIdpublic_key: PublicKeynonce: Noncereceiver_id: AccountIdblock_hash: CryptoHashactions: Vec<Action>priority_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for TransactionV1
impl BorshDeserialize for TransactionV1
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TransactionV1
impl BorshSerialize for TransactionV1
Sourceimpl Clone for TransactionV1
impl Clone for TransactionV1
Sourcefn clone(&self) -> TransactionV1
fn clone(&self) -> TransactionV1
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionV1
impl Debug for TransactionV1
Sourceimpl<'de> Deserialize<'de> for TransactionV1
impl<'de> Deserialize<'de> for TransactionV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransactionV1
impl PartialEq for TransactionV1
Sourceimpl Serialize for TransactionV1
impl Serialize for TransactionV1
impl Eq for TransactionV1
impl StructuralPartialEq for TransactionV1